@@ -6,8 +6,11 @@ use core::fmt::{self, Debug, Formatter};
 use core::hash::{Hash, Hasher};
 use core::iter::FromIterator;
 use core::mem::MaybeUninit;
-use core::ops::{Deref, DerefMut, Index, IndexMut, Range, RangeFull, RangeInclusive};
+use core::ops::{Deref, DerefMut, Index, IndexMut};
 use core::ptr;
+use core::slice::SliceIndex;
+
+#[cfg(feature = "std")]
 use core::str;
 
 #[cfg(feature = "std")]
@@ -44,51 +47,63 @@ impl<T, const N: usize> AsRef<[T]> for StaticVec<T, { N }> {
 
 impl<T: Clone, const N: usize> Clone for StaticVec<T, { N }> {
   #[inline]
-  fn clone(&self) -> Self {
-    let mut res = Self::new();
-    for i in 0..self.length {
-      // Safety: `self` has the same capacity as `res`, and `res` is
-      // empty, so all of the following writes are safe.
-      unsafe {
-        //`push_unchecked` (and the previously used iterator) seem to have the same optimizer problem
-        //in this "hot loop" context as `filled_with` did generally. So for loop plus `get_unchecked` it is
-        //for the time being.
-        res
-          .data
-          .get_unchecked_mut(i)
-          .write(self.get_unchecked(i).clone());
-        res.length += 1;
-      }
+  default fn clone(&self) -> Self {
+    Self {
+      data: {
+        unsafe {
+          let mut data: [MaybeUninit<T>; N] = MaybeUninit::uninit_array();
+          for i in 0..self.length {
+            // Put the clones in a separate stack-allocated array first, so we're
+            // not forced to increment `length` for the result variable one by one in order to
+            // account for the possibility of a `clone` call panicking.
+            data
+              .get_unchecked_mut(i)
+              .write(self.get_unchecked(i).clone());
+          }
+          data
+        }
+      },
+      length: self.length,
     }
-    res
   }
 
   #[inline]
-  fn clone_from(&mut self, rhs: &Self) {
+  default fn clone_from(&mut self, rhs: &Self) {
     self.truncate(rhs.length);
-    for i in 0..self.length {
-      // Safety: after the truncate, self.len <= rhs.len, which means that for
-      // every i in self, there is definitely an element at rhs[i].
-      unsafe {
-        self.get_unchecked_mut(i).clone_from(rhs.get_unchecked(i));
-      }
-    }
-    for i in self.length..rhs.length {
-      // Safety: i < rhs.length, so rhs.get_unchecked is safe. i starts at
-      // self.length, which is <= rhs.length, so there is always an available
-      // slot at self[i] to write into.
-      unsafe {
-        //Same thing with `push_unchecked` here as for `clone`.
-        self
-          .data
-          .get_unchecked_mut(i)
-          .write(rhs.get_unchecked(i).clone());
-        self.length += 1;
+    for i in 0..rhs.length {
+      if i < self.length {
+        // Safety: after the truncate, `self.len` <= `rhs.len`, which means that for
+        // every i in self, there is definitely an element at `rhs[i]`.
+        unsafe {
+          self.get_unchecked_mut(i).clone_from(rhs.get_unchecked(i));
+        }
+      } else {
+        // Safety: `i` < `rhs.length`, so `rhs.get_unchecked()` is safe. `i` starts at
+        // `self.length`, which is <= `rhs.length`, so there is always an available
+        // slot at `self[i]` to push into.
+        unsafe {
+          self.push_unchecked(rhs.get_unchecked(i).clone());
+        }
       }
     }
   }
 }
 
+impl<T: Copy, const N: usize> Clone for StaticVec<T, { N }> {
+  #[inline(always)]
+  fn clone(&self) -> Self {
+    // The code this generates is *way* more efficient than `copy_to_nonoverlapping`,
+    // and safe in this case because we're transmuting between two instances of the same type.
+    unsafe { core::mem::transmute_copy(self) }
+  }
+
+  #[inline(always)]
+  fn clone_from(&mut self, rhs: &Self) {
+    // See above comment for safety note.
+    *self = unsafe { core::mem::transmute_copy(rhs) }
+  }
+}
+
 impl<T: Debug, const N: usize> Debug for StaticVec<T, { N }> {
   #[inline(always)]
   fn fmt(&self, f: &mut Formatter) -> fmt::Result {
@@ -97,7 +112,7 @@ impl<T: Debug, const N: usize> Debug for StaticVec<T, { N }> {
 }
 
 impl<T, const N: usize> Default for StaticVec<T, { N }> {
-  ///Calls `new`.
+  /// Calls `new`.
   #[inline(always)]
   fn default() -> Self {
     Self::new()
@@ -140,8 +155,8 @@ impl<'a, T: 'a + Copy, const N: usize> Extend<&'a T> for StaticVec<T, { N }> {
 }
 
 impl<T: Copy, const N: usize> From<&[T]> for StaticVec<T, { N }> {
-  ///Creates a new StaticVec instance from the contents of `values`, using
-  ///[new_from_slice](crate::StaticVec::new_from_slice) internally.
+  /// Creates a new StaticVec instance from the contents of `values`, using
+  /// [new_from_slice](crate::StaticVec::new_from_slice) internally.
   #[inline(always)]
   fn from(values: &[T]) -> Self {
     Self::new_from_slice(values)
@@ -149,8 +164,8 @@ impl<T: Copy, const N: usize> From<&[T]> for StaticVec<T, { N }> {
 }
 
 impl<T: Copy, const N: usize> From<&mut [T]> for StaticVec<T, { N }> {
-  ///Creates a new StaticVec instance from the contents of `values`, using
-  ///[new_from_slice](crate::StaticVec::new_from_slice) internally.
+  /// Creates a new StaticVec instance from the contents of `values`, using
+  /// [new_from_slice](crate::StaticVec::new_from_slice) internally.
   #[inline(always)]
   fn from(values: &mut [T]) -> Self {
     Self::new_from_slice(values)
@@ -158,8 +173,8 @@ impl<T: Copy, const N: usize> From<&mut [T]> for StaticVec<T, { N }> {
 }
 
 impl<T, const N1: usize, const N2: usize> From<[T; N1]> for StaticVec<T, { N2 }> {
-  ///Creates a new StaticVec instance from the contents of `values`, using
-  ///[new_from_array](crate::StaticVec::new_from_array) internally.
+  /// Creates a new StaticVec instance from the contents of `values`, using
+  /// [new_from_array](crate::StaticVec::new_from_array) internally.
   #[inline(always)]
   fn from(values: [T; N1]) -> Self {
     Self::new_from_array(values)
@@ -167,8 +182,8 @@ impl<T, const N1: usize, const N2: usize> From<[T; N1]> for StaticVec<T, { N2 }>
 }
 
 impl<T: Copy, const N1: usize, const N2: usize> From<&[T; N1]> for StaticVec<T, { N2 }> {
-  ///Creates a new StaticVec instance from the contents of `values`, using
-  ///[new_from_slice](crate::StaticVec::new_from_slice) internally.
+  /// Creates a new StaticVec instance from the contents of `values`, using
+  /// [new_from_slice](crate::StaticVec::new_from_slice) internally.
   #[inline(always)]
   fn from(values: &[T; N1]) -> Self {
     Self::new_from_slice(values)
@@ -176,8 +191,8 @@ impl<T: Copy, const N1: usize, const N2: usize> From<&[T; N1]> for StaticVec<T,
 }
 
 impl<T: Copy, const N1: usize, const N2: usize> From<&mut [T; N1]> for StaticVec<T, { N2 }> {
-  ///Creates a new StaticVec instance from the contents of `values`, using
-  ///[new_from_slice](crate::StaticVec::new_from_slice) internally.
+  /// Creates a new StaticVec instance from the contents of `values`, using
+  /// [new_from_slice](crate::StaticVec::new_from_slice) internally.
   #[inline(always)]
   fn from(values: &mut [T; N1]) -> Self {
     Self::new_from_slice(values)
@@ -200,98 +215,25 @@ impl<T: Hash, const N: usize> Hash for StaticVec<T, { N }> {
   }
 }
 
-impl<T, const N: usize> Index<usize> for StaticVec<T, { N }> {
-  type Output = T;
-  ///Asserts that `index` is less than the current length of the StaticVec,
-  ///and if so returns the value at that position as a constant reference.
+impl<T, I: SliceIndex<[T]>, const N: usize> Index<I> for StaticVec<T, { N }> {
+  type Output = I::Output;
   #[inline(always)]
-  fn index(&self, index: usize) -> &Self::Output {
-    assert!(index < self.length);
-    unsafe { self.data.get_unchecked(index).get_ref() }
+  fn index(&self, index: I) -> &Self::Output {
+    self.as_slice().index(index)
   }
 }
 
-impl<T, const N: usize> IndexMut<usize> for StaticVec<T, { N }> {
-  ///Asserts that `index` is less than the current length of the StaticVec,
-  ///and if so returns the value at that position as a mutable reference.
+impl<T, I: SliceIndex<[T]>, const N: usize> IndexMut<I> for StaticVec<T, { N }> {
   #[inline(always)]
-  fn index_mut(&mut self, index: usize) -> &mut Self::Output {
-    assert!(index < self.length);
-    unsafe { self.data.get_unchecked_mut(index).get_mut() }
-  }
-}
-
-impl<T, const N: usize> Index<Range<usize>> for StaticVec<T, { N }> {
-  type Output = [T];
-  ///Asserts that the lower bound of `index` is less than its upper bound,
-  ///and that its upper bound is less than or equal to the current length of the StaticVec,
-  ///and if so returns a constant reference to a slice of elements `index.start..index.end`.
-  #[inline(always)]
-  fn index(&self, index: Range<usize>) -> &Self::Output {
-    assert!(index.start < index.end && index.end <= self.length);
-    unsafe { &*(self.data.get_unchecked(index) as *const [MaybeUninit<T>] as *const [T]) }
-  }
-}
-
-impl<T, const N: usize> IndexMut<Range<usize>> for StaticVec<T, { N }> {
-  ///Asserts that the lower bound of `index` is less than its upper bound,
-  ///and that its upper bound is less than or equal to the current length of the StaticVec,
-  ///and if so returns a mutable reference to a slice of elements `index.start..index.end`.
-  #[inline(always)]
-  fn index_mut(&mut self, index: Range<usize>) -> &mut Self::Output {
-    assert!(index.start < index.end && index.end <= self.length);
-    unsafe { &mut *(self.data.get_unchecked_mut(index) as *mut [MaybeUninit<T>] as *mut [T]) }
-  }
-}
-
-impl<T, const N: usize> Index<RangeFull> for StaticVec<T, { N }> {
-  type Output = [T];
-  ///Returns a constant reference to a slice consisting of `0..self.length`
-  ///elements of the StaticVec, using [as_slice](crate::StaticVec::as_slice) internally.
-  #[inline(always)]
-  fn index(&self, _index: RangeFull) -> &Self::Output {
-    self.as_slice()
-  }
-}
-
-impl<T, const N: usize> IndexMut<RangeFull> for StaticVec<T, { N }> {
-  ///Returns a mutable reference to a slice consisting of `0..self.length`
-  ///elements of the StaticVec, using [as_mut_slice](crate::StaticVec::as_mut_slice) internally.
-  #[inline(always)]
-  fn index_mut(&mut self, _index: RangeFull) -> &mut Self::Output {
-    self.as_mut_slice()
-  }
-}
-
-impl<T, const N: usize> Index<RangeInclusive<usize>> for StaticVec<T, { N }> {
-  type Output = [T];
-  ///Asserts that the lower bound of `index` is less than or equal to its upper bound,
-  ///and that its upper bound is less than the current length of the StaticVec,
-  ///and if so returns a constant reference to a slice of elements `index.start()..=index.end()`.
-  #[allow(clippy::op_ref)]
-  #[inline(always)]
-  fn index(&self, index: RangeInclusive<usize>) -> &Self::Output {
-    assert!(index.start() <= index.end() && index.end() < &self.length);
-    unsafe { &*(self.data.get_unchecked(index) as *const [MaybeUninit<T>] as *const [T]) }
-  }
-}
-
-impl<T, const N: usize> IndexMut<RangeInclusive<usize>> for StaticVec<T, { N }> {
-  ///Asserts that the lower bound of `index` is less than or equal to its upper bound,
-  ///and that its upper bound is less than the current length of the StaticVec,
-  ///and if so returns a mutable reference to a slice of elements `index.start()..=index.end()`.
-  #[allow(clippy::op_ref)]
-  #[inline(always)]
-  fn index_mut(&mut self, index: RangeInclusive<usize>) -> &mut Self::Output {
-    assert!(index.start() <= index.end() && index.end() < &self.length);
-    unsafe { &mut *(self.data.get_unchecked_mut(index) as *mut [MaybeUninit<T>] as *mut [T]) }
+  fn index_mut(&mut self, index: I) -> &mut Self::Output {
+    self.as_mut_slice().index_mut(index)
   }
 }
 
 #[cfg(feature = "std")]
 #[doc(cfg(feature = "std"))]
 impl<T, const N: usize> Into<Vec<T>> for &mut StaticVec<T, { N }> {
-  ///Functionally equivalent to [into_vec](crate::StaticVec::into_vec).
+  /// Functionally equivalent to [into_vec](crate::StaticVec::into_vec).
   #[inline(always)]
   fn into(self) -> Vec<T> {
     self.into_vec()
@@ -301,7 +243,7 @@ impl<T, const N: usize> Into<Vec<T>> for &mut StaticVec<T, { N }> {
 impl<'a, T: 'a, const N: usize> IntoIterator for &'a StaticVec<T, { N }> {
   type IntoIter = StaticVecIterConst<'a, T>;
   type Item = &'a T;
-  ///Returns a `StaticVecIterConst` over the StaticVec's inhabited area.
+  /// Returns a `StaticVecIterConst` over the StaticVec's inhabited area.
   #[inline(always)]
   fn into_iter(self) -> Self::IntoIter {
     self.iter()
@@ -311,7 +253,7 @@ impl<'a, T: 'a, const N: usize> IntoIterator for &'a StaticVec<T, { N }> {
 impl<'a, T: 'a, const N: usize> IntoIterator for &'a mut StaticVec<T, { N }> {
   type IntoIter = StaticVecIterMut<'a, T>;
   type Item = &'a mut T;
-  ///Returns a `StaticVecIterMut` over the StaticVec's inhabited area.
+  /// Returns a `StaticVecIterMut` over the StaticVec's inhabited area.
   #[inline(always)]
   fn into_iter(self) -> Self::IntoIter {
     self.iter_mut()
@@ -362,8 +304,8 @@ impl_partial_ord_with_as_slice_against_slice!(&mut [T1], StaticVec<T2, { N }>);
 /// [`Cursor`] or [`[T] as Read`][slice-read] for more efficient
 /// ways to read out of a `StaticVec` without mutating it.
 ///
-/// [`Cursor`]: https://doc.rust-lang.org/stable/std/io/struct.Cursor.html
-/// [slice-read]: https://doc.rust-lang.org/stable/std/primitive.slice.html#impl-Read]
+/// [`Cursor`]: https://doc.rust-lang.org/nightly/std/io/struct.Cursor.html
+/// [slice-read]: https://doc.rust-lang.org/nightly/std/primitive.slice.html#impl-Read]
 #[cfg(feature = "std")]
 impl<const N: usize> Read for StaticVec<u8, { N }> {
   #[inline(always)]
