@@ -3,6 +3,22 @@ use core::cmp::{Ordering, PartialOrd};
 use core::intrinsics;
 use core::mem::MaybeUninit;
 
+#[cfg(not(miri))]
+#[inline(always)]
+pub(crate) const fn distance_between<T>(dest: *const T, origin: *const T) -> usize {
+  unsafe {
+    if intrinsics::size_of::<T>() > 0 {
+      intrinsics::exact_div(
+        (dest as usize).wrapping_sub(origin as usize),
+        intrinsics::size_of::<T>(),
+      )
+    } else {
+      (dest as usize).wrapping_sub(origin as usize)
+    }
+  }
+}
+
+#[cfg(miri)]
 #[inline(always)]
 pub(crate) fn distance_between<T>(dest: *const T, origin: *const T) -> usize {
   unsafe {
@@ -35,7 +51,7 @@ where T: Copy {
   StaticVec::<T, { COUNT }> {
     data: {
       unsafe {
-        let mut data: [MaybeUninit<T>; COUNT] = MaybeUninit::uninit().assume_init();
+        let mut data: [MaybeUninit<T>; COUNT] = MaybeUninit::uninit_array();
         for i in 0..COUNT {
           data.get_unchecked_mut(i).write(value);
         }
