@@ -2,6 +2,10 @@
 
 use staticvec::*;
 
+#[cfg(not(miri))]
+#[cfg(feature = "std")]
+use cool_asserts::assert_panics;
+
 #[derive(Debug)]
 struct Struct {
   s: &'static str,
@@ -9,8 +13,8 @@ struct Struct {
 
 impl Drop for Struct {
   fn drop(&mut self) {
-    //This won't do anything observable in the test context, but it
-    //works as a placeholder.
+    // This won't do anything observable in the test context, but it
+    // works as a placeholder.
     println!("Dropping Struct with value: {}", self.s)
   }
 }
@@ -42,6 +46,7 @@ fn as_slice() {
   assert_eq!(buffer.as_slice(), &[1, 2, 3, 5, 8]);
 }
 
+#[cfg(feature = "std")]
 #[test]
 fn bounds_to_string() {
   let mut v = staticvec![1, 2, 3, 4];
@@ -83,7 +88,6 @@ fn clone() {
 fn clone_from_shorter() {
   let src: StaticVec<u32, { 20 }> = (1..10).collect();
   let mut dst: StaticVec<u32, { 20 }> = (0..15).collect();
-
   dst.clone_from(&src);
   assert_eq!(dst, src);
 }
@@ -92,7 +96,6 @@ fn clone_from_shorter() {
 fn clone_from_longer() {
   let src: StaticVec<u32, { 20 }> = (0..15).collect();
   let mut dst: StaticVec<u32, { 20 }> = (1..10).collect();
-
   dst.clone_from(&src);
   assert_eq!(dst, src);
 }
@@ -174,6 +177,16 @@ fn filled_with() {
   assert_eq!(v[3], 4);
 }
 
+#[test]
+fn filled_with_by_index() {
+  let v = StaticVec::<usize, 64>::filled_with_by_index(|i| i + 1);
+  assert_eq!(v.len(), 64);
+  assert_eq!(v[0], 1);
+  assert_eq!(v[1], 2);
+  assert_eq!(v[2], 3);
+  assert_eq!(v[3], 4);
+}
+
 #[test]
 fn first() {
   let v = staticvec![1, 2, 3];
@@ -216,11 +229,24 @@ fn get_unchecked_mut() {
 #[test]
 fn index() {
   let vec = staticvec![0, 1, 2, 3, 4];
+  assert_eq!(vec[3], 3);
   assert_eq!(vec[1..4], [1, 2, 3]);
   assert_eq!(vec[1..=1], [1]);
   assert_eq!(vec[1..3], [1, 2]);
   assert_eq!(vec[1..=3], [1, 2, 3]);
   assert_eq!(vec[..], [0, 1, 2, 3, 4]);
+  // Because this block includes obviously-violated bounds checks, miri
+  // complains about it
+  #[cfg(not(miri))]
+  #[cfg(feature = "std")]
+  {
+    // Check bounds checking
+    assert_panics!(vec[10]);
+    assert_panics!(&vec[..10]);
+    assert_panics!(&vec[10..]);
+    assert_panics!(&vec[10..15]);
+    assert_panics!(&vec[1..0]);
+  }
 }
 
 #[test]
@@ -261,6 +287,7 @@ fn is_not_full() {
   assert!(v.is_not_full());
 }
 
+#[cfg(feature = "std")]
 #[test]
 fn into_vec() {
   let mut v = staticvec![
@@ -333,8 +360,8 @@ fn partial_eq() {
   assert_eq!(StaticVec::<i32, 0>::new(), StaticVec::<i32, 0>::new());
   assert_eq!(StaticVec::<i32, 0>::new(), &StaticVec::<i32, 0>::new());
   assert_eq!(StaticVec::<i32, 0>::new(), &mut StaticVec::<i32, 0>::new());
-  //assert_eq! is written in a way that's limited by LengthAtMost32, so I can't
-  //use it for the next part.
+  // assert_eq! is written in a way that's limited by LengthAtMost32, so I can't
+  // use it for the next part.
   if staticvec![1; 64] != [1; 64] {
     panic!();
   }
@@ -363,7 +390,7 @@ fn partial_eq() {
 
 #[test]
 fn partial_ord() {
-  //TODO: add more here.
+  // TODO: add more here.
   assert!(staticvec![1] < staticvec![2]);
   assert!(staticvec![1] > []);
   assert!(staticvec![1] <= &staticvec![2]);
@@ -602,7 +629,7 @@ fn try_push() {
 #[cfg(feature = "std")]
 #[test]
 fn write() {
-  //From arrayvec
+  // From arrayvec
   let mut v = StaticVec::<u8, 8>::new();
   write!(&mut v, "\x01\x02\x03").unwrap();
   assert_eq!(&v[..], &[1, 2, 3]);
